@@ -1,6 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# Copyright (c) 2017 Satpy developers
+# Copyright (c) 2017-2023 Satpy developers
 #
 # This file is part of satpy.
 #
@@ -29,6 +27,10 @@ import xarray as xr
 
 from satpy.enhancements import create_colormap, on_dask_array, on_separate_bands, using_map_blocks
 
+# NOTE:
+# The following fixtures are not defined in this file, but are used and injected by Pytest:
+# - tmp_path
+
 
 def run_and_check_enhancement(func, data, expected, **kwargs):
     """Perform basic checks that apply to multiple tests."""
@@ -490,3 +492,84 @@ def test_on_dask_array():
     arr = xr.DataArray(da.zeros((3, 10, 10), dtype=int, chunks=5), dims=['bands', 'y', 'x'])
     res = dask_func(arr)
     assert res.shape == arr.shape
+
+
+@pytest.fixture
+def fake_area():
+    """Return a fake 2×2 area."""
+    from pyresample.geometry import create_area_def
+    return create_area_def("wingertsberg", 4087, area_extent=[-2_000, -2_000, 2_000, 2_000], shape=(2, 2))
+
+
+_nwcsaf_props = {
+     'cma': ('cma_pal', 'cloudmask', 'CMA', "uint8"),
+     'ct': ('ct_pal', 'cloudtype', 'CT', "uint8"),
+     'ctth_alti': ('ctth_alti_pal', 'cloud_top_height', 'CTTH', "float64"),
+     'ctth_pres': ('ctth_pres_pal', 'cloud_top_pressure', 'CTTH', "float64"),
+     'ctth_tempe': ('ctth_tempe_pal', 'cloud_top_temperature', 'CTTH', "float64"),
+     'cmic_phase': ('cmic_phase_pal', 'cloud_top_phase', 'CMIC', "uint8"),
+     'cmic_reff': ('cmic_reff_pal', 'cloud_drop_effective_radius', 'CMIC', "float64"),
+     'cmic_cot': ('cmic_cot_pal', 'cloud_optical_thickness', 'CMIC', "float64"),
+     'cmic_lwp': ('cmic_lwp_pal', 'cloud_liquid_water_path', 'CMIC', "float64"),
+     'cmic_iwp': ('cmic_iwp_pal', 'cloud_ice_water_path', 'CMIC', "float64"),
+     'pc': ('pc_pal', 'precipitation_probability', 'PC', "uint8"),
+     'crr': ('crr_pal', 'convective_rain_rate', 'CRR', "uint8"),
+     'crr_accum': ('crr_pal', 'convective_precipitation_hourly_accumulation', 'CRR', "uint8"),
+     'ishai_tpw': ('ishai_tpw_pal', 'total_precipitable_water', 'iSHAI', "float64"),
+     'ishai_shw': ('ishai_shw_pal', 'showalter_index', 'iSHAI', "float64"),
+     'ishai_li': ('ishai_li_pal', 'lifted_index', 'iSHAI', "float64"),
+     'ci_prob30': ('ci_pal', 'convection_initiation_prob30', 'CI', "float64"),
+     'ci_prob60': ('ci_pal', 'convection_initiation_prob60', 'CI', "float64"),
+     'ci_prob90': ('ci_pal', 'convection_initiation_prob90', 'CI', "float64"),
+     'asii_turb_trop_prob': ('asii_turb_prob_pal', 'asii_prob', 'ASII-NG', "float64"),
+     'MapCellCatType': ('MapCellCatType_pal', 'rdt_cell_type', 'RDT-CW', "uint8")}
+
+
+@pytest.mark.parametrize(
+        "data",
+        ['cma', 'ct', 'ctth_alti', 'ctth_pres', 'ctth_tempe', 'cmic_phase',
+            'cmic_reff', 'cmic_cot', 'cmic_lwp', 'cmic_iwp', 'pc', 'crr',
+            'crr_accum', 'ishai_tpw', 'ishai_shw', 'ishai_li', 'ci_prob30',
+            'ci_prob60', 'ci_prob90', 'asii_turb_trop_prob', 'MapCellCatType']
+        )
+def test_producing_mode_p(fake_area, tmp_path, data):
+    """Test producing mode p with  palettizer and ancillary variables."""
+    from satpy.writers import get_enhanced_image
+
+    from ... import Scene
+    (palette, comp, label, dtp) = _nwcsaf_props[data]
+    rng = (0, 100) if dtp == "uint8" else (-100, 1000)
+    fk = tmp_path / f"S_NWC_{label:s}_MSG2_MSG-N-VISIR_20220124T094500Z.nc"
+    # create a minimally fake netCDF file, otherwise satpy won't load the
+    # composite
+    ds = xr.Dataset(
+            coords={"nx": [0], "ny": [0]},
+            attrs={
+                "source": "satpy unit test",
+                "satellite_identifier": "pranksat",
+                "time_coverage_start": "0001-01-01T00:00:00Z",
+                "time_coverage_end": "0001-01-01T01:00:00Z"
+                })
+    ds.to_netcdf(fk)
+    sc = Scene(filenames=[os.fspath(fk)], reader=["nwcsaf-geo"])
+    sc[palette] = xr.DataArray(
+            da.tile(da.arange(256), [3, 1]).T,
+            dims=("pal02_colors", "pal_RGB"))
+    fake_alti = da.linspace(rng[0], rng[1], 4, chunks=2, dtype=dtp).reshape(2, 2)
+    sc[data] = xr.DataArray(
+            fake_alti,
+            dims=("y", "x"),
+            attrs={
+                "area": fake_area,
+                "ancillary_variables": [sc[palette]],
+                "valid_range": rng})
+    sc.load([comp])
+    im = get_enhanced_image(sc[comp])
+    assert im.mode == "P"
+    np.testing.assert_array_equal(im.data.coords["bands"], ["P"])
+    if dtp == "float64":
+        np.testing.assert_allclose(
+                im.data.sel(bands="P"),
+                ((fake_alti - rng[0]) * (255/np.ptp(rng))).round())
+    else:
+        np.testing.assert_allclose(im.data.sel(bands="P"), fake_alti)
