@@ -25,6 +25,10 @@ import numpy as np
 import pytest
 from pyhdf.SD import SD, SDC
 
+# NOTE:
+# The following fixtures are not defined in this file, but are used and injected by Pytest:
+# - tmpdir_factory
+
 # Level 1 Fixtures
 
 AVAILABLE_1KM_VIS_PRODUCT_NAMES = [str(x) for x in range(8, 13)]
@@ -301,7 +305,7 @@ def _create_core_metadata(file_shortname: str) -> str:
                     "END_OBJECT = ASSOCIATEDPLATFORMINSTRUMENTSENSORCONTAINER\n\n" \
                     "END_GROUP              = ASSOCIATEDPLATFORMINSTRUMENTSENSOR\n\n"
     collection_metadata = "GROUP = COLLECTIONDESCRIPTIONCLASS\n\nOBJECT = SHORTNAME\nNUM_VAL = 1\n" \
-                          f"VALUE = \"{file_shortname}\"\nEND_OBJECT = SHORTNAME\n\n" \
+                          f"VALUE = {file_shortname!r}\nEND_OBJECT = SHORTNAME\n\n" \
                           "OBJECT = VERSIONID\nNUM_VAL = 1\nVALUE = 6\nEND_OBJECT = VERSIONID\n\n" \
                           "END_GROUP = COLLECTIONDESCRIPTIONCLASS\n\n"
     core_metadata_header += "\n\n" + inst_metadata + collection_metadata
