@@ -1,6 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# Copyright (c) 2009-2019 Satpy developers
+# Copyright (c) 2009-2023 Satpy developers
 #
 # This file is part of satpy.
 #
@@ -23,6 +21,7 @@ from __future__ import annotations
 import contextlib
 import datetime
 import logging
+import pathlib
 import warnings
 from contextlib import contextmanager
 from copy import deepcopy
@@ -629,6 +628,8 @@ def _sort_files_to_local_remote_and_fsfiles(filenames):
     for f in filenames:
         if isinstance(f, FSFile):
             fs_files.append(f)
+        elif isinstance(f, pathlib.Path):
+            local_files.append(f)
         elif urlparse(f).scheme in ('', 'file') or "\\" in f:
             local_files.append(f)
         else:
@@ -659,9 +660,12 @@ def get_storage_options_from_reader_kwargs(reader_kwargs):
 def _get_storage_dictionary_options(reader_kwargs):
     storage_opt_dict = {}
     shared_storage_options = reader_kwargs.pop("storage_options", {})
+    if not reader_kwargs:
+        # no other reader kwargs
+        return shared_storage_options
     for reader_name, rkwargs in reader_kwargs.items():
         if not isinstance(rkwargs, dict):
-            # reader kwargs are not per-reader, return a single dictonary of storage options
+            # reader kwargs are not per-reader, return a single dictionary of storage options
             return shared_storage_options
         if shared_storage_options:
             # set base storage options if there are any
@@ -678,3 +682,26 @@ def import_error_helper(dependency_name):
         yield
     except ImportError as err:
         raise ImportError(err.msg + f" It can be installed with the {dependency_name} package.")
+
+
+def find_in_ancillary(data, dataset):
+    """Find a dataset by name in the ancillary vars of another dataset.
+
+    Args:
+        data (xarray.DataArray):
+            Array for which to search the ancillary variables
+        dataset (str):
+            Name of ancillary variable to look for.
+    """
+    matches = [x for x in data.attrs["ancillary_variables"] if x.attrs.get("name") == dataset]
+    cnt = len(matches)
+    if cnt < 1:
+        raise ValueError(
+            f"Could not find dataset named {dataset:s} in ancillary "
+            f"variables for dataset {data.attrs.get('name')!r}")
+    if cnt > 1:
+        raise ValueError(
+            f"Expected exactly one dataset named {dataset:s} in ancillary "
+            f"variables for dataset {data.attrs.get('name')!r}, "
+            f"found {cnt:d}")
+    return matches[0]
